Get value from the metadata service.
The suffix is appended to http://${GCE_METADATA_HOST}/computeMetadata/v1/.
If the GCE_METADATA_HOST environment variable is not defined, a default of
169.254.169.254 will be used instead.
Get value from the metadata service.
The suffix is appended to http://${GCE_METADATA_HOST}/computeMetadata/v1/.
If the GCE_METADATA_HOST environment variable is not defined, a default of
169.254.169.254 will be used instead.